==> react-native-phrase-sdk-1.1.4.tgz: package/phrase.js <==
import "react-native-url-polyfill/auto";
import { md5 } from "./md5";
import PhraseApi from "./phrase_api";
import PhraseRepository from "./phrase_repository";

const PHRASE_SDK_VERSION = require("./package.json").version;
const DEFAULT_URL = "https://ota.phraseapp.com";

export default class Phrase {
  constructor (
    distribution,
    environment,
    appVersion,
    fileFormat,
    host = DEFAULT_URL
  ) {
    this.distribution = distribution;
    this.environment = environment;
    this.appVersion = appVersion;
    this.fileFormat = fileFormat;

    this.repo = new PhraseRepository();
    this.api = new PhraseApi(host);
  }

  static log (s) {
    console.log("PHRASE: " + s);
  }

  static localeHash (a, b, c) {
    return md5(a + "-" + b + "-" + c);
  }

  async loadFromCache (localeCode) {
    const localeHash = Phrase.localeHash(
      this.distribution,
      this.environment,
      localeCode
    );
    return await this.repo.getCache(localeHash);
  }

  async updateFromApi (localeCode) {
    const localeHash = Phrase.localeHash(
      this.distribution,
      this.environment,
      localeCode
    );
    try {
      const response = await this.api.getTranslations(
        this.distribution,
        this.environment,
        localeCode,
        this.fileFormat,
        await this.repo.getUuid(),
        PHRASE_SDK_VERSION,
        await this.repo.getLastUpdate(),
        await this.repo.getVersion(localeHash),
        this.appVersion
      );
      if (response != null) {
        Phrase.log("OTA update for `" + localeCode + "`: OK");
        await this.repo.setCache(localeHash, response.json);
        await this.repo.setLastUpdate();
        await this.repo.setVersion(localeHash, response.version);
      } else if (response == null) {
        Phrase.log("OTA update for `" + localeCode + "`: NOT MODIFIED");
      }
    } catch (e) {
      Phrase.log("OTA update for `" + localeCode + "`: ERROR: " + e);
    }
  }

  async requestTranslation (localeCode) {
    this.updateFromApi(localeCode); // Perform translation update in the background
    return await this.loadFromCache(localeCode);
  }
}

module.exports = Phrase;

==> react-native-phrase-sdk-1.2.0-rc1.tgz: package/phrase.js <==
import "react-native-url-polyfill/auto";
import { md5 } from "./md5";
import PhraseApi from "./phrase_api";
import PhraseRepository from "./phrase_repository";

const PHRASE_SDK_VERSION = require("./package.json").version;
const DEFAULT_URL = "https://ota.phraseapp.com";

export default class Phrase {
  constructor (
    distribution,
    environment,
    appVersion,
    fileFormat,
    host = DEFAULT_URL,
    customUuid = null
  ) {
    this.distribution = distribution;
    this.environment = environment;
    this.appVersion = appVersion;
    this.fileFormat = fileFormat;
    this.customUuid = customUuid;

    this.repo = new PhraseRepository(this.customUuid);
    this.api = new PhraseApi(host);
  }

  static log (s) {
    console.log("PHRASE: " + s);
  }

  static localeHash (a, b, c) {
    return md5(a + "-" + b + "-" + c);
  }

  async loadFromCache (localeCode) {
    const localeHash = Phrase.localeHash(
      this.distribution,
      this.environment,
      localeCode
    );
    return await this.repo.getCache(localeHash);
  }

  async updateFromApi (localeCode) {
    const localeHash = Phrase.localeHash(
      this.distribution,
      this.environment,
      localeCode
    );
    try {
      const response = await this.api.getTranslations(
        this.distribution,
        this.environment,
        localeCode,
        this.fileFormat,
        await this.repo.getUuid(),
        PHRASE_SDK_VERSION,
        await this.repo.getLastUpdate(),
        await this.repo.getVersion(localeHash),
        this.appVersion
      );
      if (response != null) {
        Phrase.log("OTA update for `" + localeCode + "`: OK");
        await this.repo.setCache(localeHash, response.json);
        await this.repo.setLastUpdate();
        await this.repo.setVersion(localeHash, response.version);
      } else if (response == null) {
        Phrase.log("OTA update for `" + localeCode + "`: NOT MODIFIED");
      }
    } catch (e) {
      Phrase.log("OTA update for `" + localeCode + "`: ERROR: " + e);
    }
  }

  async requestTranslation (localeCode) {
    this.updateFromApi(localeCode); // Perform translation update in the background
    return await this.loadFromCache(localeCode);
  }
}

module.exports = Phrase;
